<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: VictorThemes
 * URL: http://themeforest.net/user/VictorThemes
 */

/* Exclude category from blog */
if( ! function_exists( 'cascara_vt_excludeCat' ) ) {
  function cascara_vt_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'cascara_vt_excludeCat');
}

/**
 * Filter the categories archive widget to add a span around post count
 */
function cascara_cat_count_span( $links ) {
  $links = str_replace( '</a> (', '</a><span class="post-count">', $links );
  $links = str_replace( ')', '</span>', $links );
  return $links;
}
add_filter( 'wp_list_categories', 'cascara_cat_count_span' );

/**
 * Filter the archives widget to add a span around post count
 */
function cascara_archive_count_span( $links ) {
  $links = str_replace( '</a>&nbsp;(', '</a><span class="post-count">', $links );
  $links = str_replace( ')', '</span>', $links );
  return $links;
}
add_filter( 'get_archives_link', 'cascara_archive_count_span' );

/*
 * Set post views count using post meta
 */
function cascara_getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0";
    }
    return $count;
}
function cascara_setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// Remove issues with prefetching adding extra views
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

/* Excerpt Length */
class CascaraExcerpt {

  // Default length (by WordPress)
  public static $length = 55;

  // Output: cascara_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    CascaraExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'CascaraExcerpt::new_length');
    CascaraExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(CascaraExcerpt::$types[CascaraExcerpt::$length]) )
      return CascaraExcerpt::$types[CascaraExcerpt::$length];
    else
      return CascaraExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt Length
if( ! function_exists( 'cascara_excerpt' ) ) {
  function cascara_excerpt($length = 55) {
    CascaraExcerpt::length($length);
  }
}

if ( ! function_exists( 'cascara_new_excerpt_more' ) ) {
  function cascara_new_excerpt_more( $more ) {
    return '';
  }
  add_filter('excerpt_more', 'cascara_new_excerpt_more');
}

/* Tag Cloud Widget - Remove Inline Font Size */
if( ! function_exists( 'cascara_vt_tag_cloud' ) ) {
  function cascara_vt_tag_cloud($tag_string){
    return preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
  }
  add_filter('wp_generate_tag_cloud', 'cascara_vt_tag_cloud', 10, 3);
}

/* Password Form */
if( ! function_exists( 'cascara_vt_password_form' ) ) {
  function cascara_vt_password_form( $output ) {
    $output = str_replace( 'type="submit"', 'type="submit" class=""', $output );
    return $output;
  }
  add_filter('the_password_form' , 'cascara_vt_password_form');
}

/* Maintenance Mode */
if( ! function_exists( 'cascara_vt_maintenance_mode' ) ) {
  function cascara_vt_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );

    if ( ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'cascara_vt_maintenance_mode', 1 );
}

/* Widget Layouts */
if ( ! function_exists( 'cascara_vt_footer_widgets' ) ) {
  function cascara_vt_footer_widgets() {

    $output = '';
    $footer_widget_layout = cs_get_option('footer_widget_layout');

    if( $footer_widget_layout ) {

      switch ( $footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col-md-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col-md-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col-md-3 col-sm-6'); break;
        case 5: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 6: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 2); break;
        case 7: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 3); break;
        case 8: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 9: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 4); break;
        case 10: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        default : $widget = array('piece' => 4, 'class' => 'col-md-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {
         $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];
        $output .= '<div class="'. $widget_class .'">';
        ob_start();
        if (is_active_sidebar('footer-'. $i)) {
          dynamic_sidebar( 'footer-'. $i );
        }
        $output .= ob_get_clean();
        $output .= '</div>';

      }

      switch ( $footer_widget_layout ) {
        case 10:
        $output .= '<div class="footer-widget-secondary"> <div class="row">';
        $output .= '<div class="col-md-6 widget-left">';
        ob_start();
        if (is_active_sidebar('footer-4')) {
          dynamic_sidebar( 'footer-4' );
        }
        $output .= ob_get_clean();
        $output .= '</div>';
        $output .= '<div class="col-md-6 widget-right">';
        ob_start();
        if (is_active_sidebar('footer-5')) {
          dynamic_sidebar( 'footer-5' );
        }
        $output .= ob_get_clean();
        $output .= '</div>';
        $output .= '</div></div>';
      }

    }

    return $output;

  }
}

if( ! function_exists( 'cascara_vt_top_bar' ) ) {
  function cascara_vt_top_bar() {

    $out     = '';

    if ( ( cs_get_option( 'top_left' ) || cs_get_option( 'top_right' ) ) ) {
      $out .= '<div class="cscra-topbar"><div class="container"><div class="row">';
      $out .= cascara_vt_top_bar_modules( 'left' );
      $out .= cascara_vt_top_bar_modules( 'right' );
      $out .= '</div></div></div>';
    }

    return $out;
  }
}

/* WP Link Pages */
if ( ! function_exists( 'cascara_wp_link_pages' ) ) {
  function cascara_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="wp-link-pages">' . esc_html__( 'Pages:', 'cascara' ),
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}

if ( ! function_exists( 'cascara_post_cat' ) ) {
  function cascara_post_cat() {

    global $post;
    $cats = get_the_category( $post->ID ); ?>
    <div class="post-category" >
    <?php
    foreach ($cats as $cat) {
      $term = get_category_by_slug( $cat->slug );
      $term_data = get_term_meta( $term->term_id, '_custom_taxonomy_options', true );
      $category_link = get_category_link( $term->term_id );
      if($term_data){
        $cat_color = $term_data['cat_color'];
        $cat_bg_color = $term_data['cat_bg_color'];
      } else {
        $cat_color = '';
        $cat_bg_color = '';
      }
      $category_color = $cat_color ? ' data-color='.$cat_color.'' : '';
      $cat_bg_color = $cat_bg_color ? ' data-bgcolor='.$cat_bg_color.'' : '';
        $name = $cat->name; ?>
        <a href="<?php echo esc_url($category_link); ?>" <?php echo esc_attr($category_color) .esc_attr($cat_bg_color); ?>><?php echo esc_html($name); ?></a> 
      <?php
    } ?>
    </div>
    <?php
  }
}

/* Metas Two */
if ( ! function_exists( 'cascara_post_metas_three' ) ) {
  function cascara_post_metas_three() {
  $metas_hide = (array) cs_get_option( 'theme_metas_hide' );
  global $post;
  ?>
    <div class="post-meta">
      <ul>
      <?php  if ( !in_array( 'views', $metas_hide ) ) {
        if ( function_exists( 'cascara_post_views_two' ) ) {
          cascara_post_views_two($post->ID);
        }
      }
      if ( !in_array( 'date', $metas_hide ) ) { // Date Hide ?>
        <li><i class="fa fa-clock-o" aria-hidden="true"></i> <?php echo esc_html(get_the_date()); ?></li>
      <?php } if ( !in_array( 'comments', $metas_hide ) ) { // Comments Hide
        if (get_comments_number()!=0) {
         ?>
        <li><?php echo '<i class="fa fa-commenting-o"></i>';
        comments_popup_link( '0', '1', '%', '', '' );  ?></li>
        <?php } } ?>
      </ul>
    </div>
  <?php
  }
}

/* Metas */
if ( ! function_exists( 'cascara_post_metas_two' ) ) {
  function cascara_post_metas_two() {
  $metas_hide = (array) cs_get_option( 'theme_metas_hide' );
  global $post;
  ?>
    <div class="post-meta">
      <ul>
      <?php if ( !in_array( 'views', $metas_hide ) ) {
        if ( function_exists( 'cascara_post_views_two' ) ) {
          cascara_post_views_two($post->ID);
        }
      }
      if ( !in_array( 'author', $metas_hide ) ) { // Author Hide ?>
        <li><i class="fa fa-user-o" aria-hidden="true"></i><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"> <?php echo esc_html(get_the_author()); ?></a></li>
      <?php } if ( !in_array( 'date', $metas_hide ) ) { // Date Hide ?>
        <li><i class="fa fa-clock-o" aria-hidden="true"></i> <?php echo esc_html(get_the_date()); ?></li>
      <?php } if ( !in_array( 'comments', $metas_hide ) ) { // Comments Hide
        if (get_comments_number()!=0) {
         ?>
        <li><?php echo '<i class="fa fa-commenting-o"></i>';
        comments_popup_link( '0', '1', '%', '', '' );  ?></li>
        <?php } } ?>
      </ul>
    </div>
  <?php
  }
}

/* Author Info */
if ( ! function_exists( 'cascara_author_info' ) ) {
  function cascara_author_info() {

    if (get_the_author_meta( 'url' )) {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_the_author_meta( 'url' );
      $target = 'target="_blank"';
    } else {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $target = '';
    }

    // variables
    $author_text = cs_get_option('author_text');
    $author_text = $author_text ? $author_text : esc_html__( 'Author', 'cascara' );
    $author_content = get_the_author_meta( 'description' );
if ($author_content) {
?>
  <div class="cscra-author-info">
    <div class="author-avatar">
      <a href="<?php echo esc_url($website_url); ?>" <?php echo esc_html($target); ?>>
        <?php echo get_avatar( get_the_author_meta( 'ID' ), 100 ); ?>
      </a>
    </div>
    <div class="author-content">
      <a href="<?php echo esc_url($author_url); ?>" class="author-name"><?php echo esc_html(get_the_author_meta('first_name')).' '.esc_html(get_the_author_meta('last_name')); ?></a>
      <p><?php echo esc_html(get_the_author_meta( 'description' )); ?></p>

      <div class="cscra-social">
        <?php if (get_the_author_meta( 'facebook' )): ?><a href="<?php echo esc_url( get_the_author_meta( 'facebook' ) ); ?>" class="facebook" target="_blank"><i class="fa fa-facebook"></i></a>
        <?php endif;

        if (get_the_author_meta( 'twitter' )): ?><a href="<?php echo esc_url( get_the_author_meta( 'twitter' ) ); ?>" class="twitter" target="_blank"><i class="fa fa-twitter"></i></a>
        <?php endif;

        if (get_the_author_meta( 'pinterest' )): ?><a href="<?php echo esc_url( get_the_author_meta( 'pinterest' ) ); ?>" class="pinterest" target="_blank"><i class="fa fa-pinterest"></i></a>
        <?php endif; ?>
      </div>
    </div>
  </div>
<?php
} // if $author_content
  }
}

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'cascara_comment_modification' ) ) {
  function cascara_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>

  <<?php echo esc_attr($tag); ?> <?php comment_class('item ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-item">
    <?php endif; ?>
    <div class="comment-theme">
          <?php if ( $args['avatar_size'] != 0 ) { ?>
        <div class="comment-image">
          <?php echo get_avatar( $comment, 70 ); ?>
        </div>
        <?php  } ?>
    </div>
    <div class="comment-main-area">
      <div class="comment-wrapper">
        <div class="cscra-comments-meta">
          <h4><?php printf( '%s', get_comment_author() ); ?></h4>
          <span class="comments-date">
            <?php echo get_comment_date('d M Y'); ?>
          </span>
        </div>
        <?php if ( $comment->comment_approved == '0' ) : ?>
        <em class="comment-awaiting-moderation"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'cascara' ); ?></em>
        <?php endif; ?>
        <div class="comment-area">
          <?php comment_text(); ?>
          <div class="comments-reply">
            <?php
              comment_reply_link( array_merge( $args, array(
              'reply_text' => '<span class="comment-reply-link"><i class="fa fa-reply" aria-hidden="true"></i> '. esc_html__('Reply','cascara') .'</span>',
              'before' => '',
              'class'  => '',
              'depth' => $depth,
              'max_depth' => $args['max_depth']
              ) ) );
            ?>
          </div>
        </div>
      </div>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Comments Form - Textarea next to Normal Fields */
if( ! function_exists( 'cascara_move_comment_field' ) ) {
  add_filter( 'comment_form_fields', 'cascara_move_comment_field' );
  function cascara_move_comment_field( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
  }
}

/* Title Area */
if ( ! function_exists( 'cascara_title_area' ) ) {
  function cascara_title_area() {

    global $post, $wp_query;

    // Get post meta in all type of WP pages
    $cascara_id    = ( isset( $post ) ) ? $post->ID : 0;
    $cascara_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $cascara_id;
    $cascara_meta  = get_post_meta( $cascara_id, 'page_type_metabox', true );
    if ($cascara_meta && (!is_archive())) {
      $custom_title = $cascara_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } elseif(post_type_archive_title()) {
        post_type_archive_title();
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    /**
     * For strings with necessary HTML, use the following:
     * Note that I'm only including the actual allowed HTML for this specific string.
     * More info: https://codex.wordpress.org/Function_Reference/wp_kses
     */
    $allowed_title_area_tags = array(
        'a' => array(
          'href' => array(),
        ),
        'span' => array(
          'class' => array(),
        )
    );

    if( $custom_title ) {
      echo esc_html($custom_title);
    } elseif ( is_home() ) {
      bloginfo('description');
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'cascara' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ){
      single_cat_title();
    } elseif ( is_tag() ){
      single_tag_title(esc_html__('Posts Tagged: ', 'cascara'));
    } elseif ( is_archive() ){
      if ( is_day() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'cascara' ), $allowed_title_area_tags ), get_the_date());
      } elseif ( is_month() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'cascara' ), $allowed_title_area_tags ), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'cascara' ), $allowed_title_area_tags ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( wp_kses( __( 'Posts by: <span>%s</span>', 'cascara' ), $allowed_title_area_tags ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        esc_html_e( 'Archives', 'cascara' );
      }
    } elseif( is_404() ) {
      esc_html_e('404', 'cascara');
    } else {
      the_title();
    }

  }
}

/**
 * Pagination Function
 */
if ( ! function_exists( 'cascara_paging_nav' ) ) {
  function cascara_paging_nav($nav_query = NULL) {
    if ( function_exists('wp_pagenavi')) {
      echo '<div class="cscra-pagination"><div class="cscra-pagenavi">';
        wp_pagenavi();
      echo '</div></div>';
    } else {
      global $wp_query;
      $big = 999999999;
      $current = max( 1, get_query_var('paged') );
      $total = ($nav_query != NULL) ? $nav_query->max_num_pages : $wp_query->max_num_pages;

      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
      echo '<div class="cscra-pagination"><div class="cscra-pagenavi">';
      echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?paged=%#%',
        'prev_text' => '<i class="fa fa-angle-left"></i> ',
        'next_text' => ' <i class="fa fa-angle-right"></i>',
        'current' => $current,
        'total' => $total,
        'type' => 'list'
      ));
      echo '</div></div>';
      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
    }
  }
}

/**
 * Custom Pagination Function
 */
if ( ! function_exists( 'cascara_custom_paging_nav' ) ) {
  function cascara_custom_paging_nav($numpages = '', $pagerange = '', $paged='') {
    if (empty($pagerange)) {
      $pagerange = 2;
    }
    if (empty($paged)) {
      $paged = 1;
    } else {
      $paged = $paged;
    }
    if ($numpages == '') {
      global $wp_query;
      $numpages = $wp_query->max_num_pages;
      if(!$numpages) {
        $numpages = 1;
      }
    }
    $big = 999999999; ?>
    <div class="cscra-pagenavi">
      <?php echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?page=%#%',
        'prev_text' => '<i class="fa fa-angle-left" aria-hidden="true"></i>',
        'next_text' => '<i class="fa fa-angle-right" aria-hidden="true"></i>',
        'current' => $paged,
        'total' => $numpages,
        'type' => 'list'
      )); ?>
  </div>
<?php
  }
}

/* Added next class to wp-pagenavi*/
add_filter('wp_pagenavi_class_nextpostslink', 'cascara_pagination_nextpostslink_class');
function cascara_pagination_nextpostslink_class($class_name) {
  return 'next';
}

// Custom Post Type limit
function cascara_custom_posts_per_page( $query ) {
  if ( post_type_exists( 'team' ) ) {
    if ( is_post_type_archive() ) {
      $team_limit = cs_get_option('team_limit');
      $team_limit = $team_limit ? $team_limit : '8';
      if ( $query->query_vars['post_type'] == 'team' ) $query->query_vars['posts_per_page'] = $team_limit;
    }
  }
  return $query;
}
add_filter( 'pre_get_posts', 'cascara_custom_posts_per_page' );
